import pyttsx3
import speech_recognition as sr

engine = pyttsx3.init('sapi5')
voices = engine.getProperty('voices')
engine.setProperty('voices',voices[0].id)

def speak(audio):
    engine.say(audio)
    print(audio)
    engine.runAndWait()

def takeCommand():
    r = sr.Recognizer()
    with sr.Microphone() as source:
        r.adjust_for_ambient_noise(source)
        print("Listening...")
        r.pause_threshold = 0.7
        audio = r.listen(source)

    try:
        print("Recognizing...")   
        query = r.recognize_google(audio, language='en-in') 
        print(f"user said : {query}")

    except Exception as e:
        print("Say that again please...")
        return "none"
    return query


from setuptools import setup
setup(name = "sLIntell",
version = "1.0.1",
description = "This is a package which can speak and listen to your commands. Developed for personal use only. Copyright to Siddh Rathod",
author = "Siddh Rathod",
author_email = 'siddhrathod1@gmail.com',
license = 'MIT',
keywords = (['speak tool','listen tool']),
packages = (['sLIntell']),
install_requires = (['pyttsx3', 'speechRecognition']),
)